@@ -3,25 +3,27 @@ import yaml
 import io
 import tempfile
 
-def createTmpFolder():
+def create_tmp_folder():
     return tempfile.mkdtemp()
 
-def getPathFromRoot(path):
+def get_path_from_root(path):
     return pkg_resources.resource_filename('dcli', '/' + path)
 
-def getPathFromTemplateDir(type, path):
+def get_path_from_template_dir(type, path):
     resource_path = '/'.join(('template', type + '/' + path))
     return pkg_resources.resource_filename('dcli', resource_path)
 
-def loadYaml(path):
+def load_yaml(path):
     with open(path, 'r') as stream:
         return yaml.safe_load(stream)
 
+def open_file_from_root(path):
+    return open(get_path_from_root(path)).read()
 
-def loadFile(type, path):
-    return open(getPathFromTemplateDir(type, path)).read()
+def open_file_from_template_dir(type, path):
+    return open(get_path_from_template_dir(type, path)).read()
 
-def writeFile(path, content):
+def write_file(path, content):
     newFile = open(path, "w+")
     newFile.write(content)
     newFile.close()
